==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/WebListHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebListHeaderDescription } from "./WebListHeaderDescription";
/**
 * @hidden
 */
var WebListHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebListHeaderDescriptionMetadata, _super);
    function WebListHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebListHeaderDescriptionMetadata.b = function (a) {
        if (WebListHeaderDescriptionMetadata.a == null) {
            WebListHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebListHeaderDescriptionMetadata.c(WebListHeaderDescriptionMetadata.a);
        }
        if (a.g(WebListHeaderDescriptionMetadata.a)) {
            return;
        }
        a.s(WebListHeaderDescriptionMetadata.a);
    };
    WebListHeaderDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ListHeader");
    };
    WebListHeaderDescriptionMetadata.d = function (a) {
        WebListHeaderDescriptionMetadata.b(a);
        a.u("WebListHeader", function () { return new WebListHeaderDescription(); });
        a.t("WebListHeader", WebListHeaderDescriptionMetadata.a);
    };
    WebListHeaderDescriptionMetadata.$t = markType(WebListHeaderDescriptionMetadata, 'WebListHeaderDescriptionMetadata');
    WebListHeaderDescriptionMetadata.a = null;
    return WebListHeaderDescriptionMetadata;
}(Base));
export { WebListHeaderDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebListHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebListHeaderDescription } from "./WebListHeaderDescription";
/**
 * @hidden
 */
var WebListHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebListHeaderDescriptionMetadata, _super);
    function WebListHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebListHeaderDescriptionMetadata.b = function (a) {
        if (WebListHeaderDescriptionMetadata.a == null) {
            WebListHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebListHeaderDescriptionMetadata.c(WebListHeaderDescriptionMetadata.a);
        }
        if (a.j(WebListHeaderDescriptionMetadata.a)) {
            return;
        }
        a.y(WebListHeaderDescriptionMetadata.a);
    };
    WebListHeaderDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ListHeader");
        a.item("__tagNameWC", "String:igc-list-header");
    };
    WebListHeaderDescriptionMetadata.d = function (a) {
        WebListHeaderDescriptionMetadata.b(a);
        a.aa("WebListHeader", function () { return new WebListHeaderDescription(); });
        a.z("WebListHeader", WebListHeaderDescriptionMetadata.a);
    };
    WebListHeaderDescriptionMetadata.$t = markType(WebListHeaderDescriptionMetadata, 'WebListHeaderDescriptionMetadata');
    WebListHeaderDescriptionMetadata.a = null;
    return WebListHeaderDescriptionMetadata;
}(Base));
export { WebListHeaderDescriptionMetadata };
